---
name: Bug report
about: Report a bug (e.g., something not working as described, missing/incorrect documentation).
title: ''
labels: 'bug'
assignees: ''

---
<!--

For the Bug Report,
Include this information:
-------------------------
Command-line output of `nobrainer info`.
What were you trying to do?
What did you expect will happen?
What actually happened?
Can you replicate the behavior? If yes, how?

List the steps you performed that revealed the bug to you.
Include any code samples. Enclose them in triple back-ticks (```)
Like this:

```
<code>
```
-->
